@@ -1,4 +1,6 @@
 import copy
+import typing
+
 from ..model.snowflake import Snowflake
 
 
@@ -19,6 +21,8 @@ class EventBase:
 
 
 class DiscordObjectBase:
+    TYPING = typing.Union[int, str, Snowflake, "DiscordObjectBase"]
+
     def __init__(self, client, resp, **kwargs):
         resp.update(kwargs)
         self._cache_type = None
@@ -31,7 +35,7 @@ class DiscordObjectBase:
 
     @classmethod
     def create(cls, client, resp, **kwargs):
-        maybe_exist = client.has_cache and client.cache.get(resp["id"])
+        maybe_exist = client.has_cache and client.cache.get(resp["id"], kwargs.pop("ensure_cache_type") if "ensure_cache_type" in kwargs else None)
         if maybe_exist:
             orig = maybe_exist.raw
             for k, v in resp.items():
@@ -92,10 +96,10 @@ class FlagBase:
             self.value &= ~self.values[key]
 
     def add(self, value):
-        return self.__setattr(value, True)
+        return self.__setattr__(value, True)
 
     def remove(self, value):
-        return self.__setattr(value, False)
+        return self.__setattr__(value, False)
 
     @classmethod
     def from_value(cls, value: int):
