@@ -12,13 +12,15 @@ from ..base.model import CopyableObject, DiscordObjectBase, TypeBase, FlagBase
 
 
 class Channel(DiscordObjectBase):
+    TYPING = typing.Union[int, str, Snowflake, "Channel"]
+
     def __init__(self, client, resp, *, guild_id=None):
         super().__init__(client, resp)
         self._cache_type = "channel"
         self.type = ChannelTypes(resp["type"])
         self.guild_id = Snowflake.optional(resp.get("guild_id")) or Snowflake.ensure_snowflake(guild_id)
         self.position = resp.get("position")
-        self.permission_overwrites = [Overwrite(x) for x in resp.get("permission_overwrites", [])]
+        self.permission_overwrites = [Overwrite.create(x) for x in resp.get("permission_overwrites", [])]
         self.name = resp.get("name")
         self.topic = resp.get("topic")
         self.nsfw = resp.get("nsfw")
@@ -43,15 +45,6 @@ class Channel(DiscordObjectBase):
         self.default_auto_archive_duration = resp.get("default_auto_archive_duration")
         self.permissions = resp.get("permissions")
 
-    def create_message(self, *args, **kwargs):
-        if not self.is_messageable():
-            raise TypeError("You can't send message in this type of channel.")
-        return self.client.create_message(self, *args, **kwargs)
-
-    @property
-    def send(self):
-        return self.create_message
-
     def modify(self, **kwargs):
         if self.type.group_dm:
             return self.client.modify_group_dm_channel(self.id, **kwargs)
@@ -66,11 +59,23 @@ class Channel(DiscordObjectBase):
     def edit(self):
         return self.modify
 
-    def bulk_delete_messages(self, *messages: typing.Union[int, str, Snowflake, "Message"]):
-        return self.client.bulk_delete_messages(self, messages)
+    def delete(self, *, reason: str = None):
+        return self.client.delete_channel(self, reason=reason)
 
-    def edit_permissions(self, overwrite):
-        return self.client.edit_channel_permissions(self, overwrite)
+    def create_message(self, *args, **kwargs):
+        if not self.is_messageable():
+            raise TypeError("You can't send message in this type of channel.")
+        return self.client.create_message(self, *args, **kwargs)
+
+    @property
+    def send(self):
+        return self.create_message
+
+    def bulk_delete_messages(self, *messages: typing.Union[int, str, Snowflake, "Message"], reason: str = None):
+        return self.client.bulk_delete_messages(self, *messages, reason=reason)
+
+    def edit_permissions(self, overwrite, *, reason: str = None):
+        return self.client.edit_channel_permissions(self, overwrite, reason=reason)
 
     def request_invites(self):
         return self.client.request_channel_invites(self)
@@ -78,8 +83,8 @@ class Channel(DiscordObjectBase):
     def create_invite(self, **kwargs):
         return self.client.create_channel_invite(self, **kwargs)
 
-    def delete_permissions(self, overwrite):
-        return self.client.delete_channel_permission(self, overwrite)
+    def delete_permissions(self, overwrite, *, reason: str = None):
+        return self.client.delete_channel_permission(self, overwrite, reason=reason)
 
     def follow(self, target_channel: typing.Union[int, str, Snowflake, "Channel"]):
         return self.client.follow_news_channel(self, target_channel)
@@ -100,8 +105,8 @@ class Channel(DiscordObjectBase):
             raise AttributeError("This type of channel is not allowed to remove recipient.")
         return self.client.group_dm_remove_recipient(self, user)
 
-    def start_thread(self, message: typing.Union[int, str, Snowflake, "Message"] = None, *, name: str, auto_archive_duration: int):
-        return self.client.start_thread(self, message, name=name, auto_archive_duration=auto_archive_duration)
+    def start_thread(self, message: typing.Union[int, str, Snowflake, "Message"] = None, *, name: str, auto_archive_duration: int, reason: str = None):
+        return self.client.start_thread(self, message, name=name, auto_archive_duration=auto_archive_duration, reason=reason)
 
     def join_thread(self):
         if not self.is_thread_channel():
@@ -145,6 +150,17 @@ class Channel(DiscordObjectBase):
             raise AttributeError("This type of channel is not allowed to archive.")
         return self.modify(archived=True, locked=locked)
 
+    def to_position_param(self, position: int = None, lock_permissions: bool = None, parent: typing.Union[int, str, Snowflake, "Channel"] = None):
+        if isinstance(parent, Channel) and not parent.type.guild_category:
+            raise TypeError("parent must be category channel.")
+        param = {
+            "id": str(self.id),
+            "position": position,
+            "lock_permissions": lock_permissions,
+            "parent_id": str(int(parent))
+        }
+        return param
+
     @property
     def mention(self):
         return f"<#{self.id}>"
@@ -181,6 +197,8 @@ class VideoQualityModes(TypeBase):
 
 
 class Message(DiscordObjectBase):
+    TYPING = typing.Union[int, str, Snowflake, "Message"]
+
     def __init__(self, client, resp, *, guild_id=None, webhook_token=None, interaction_token=None, original_response=False):
         from .interactions import MessageInteraction, Component  # Prevent circular import.
         super().__init__(client, resp)
@@ -196,8 +214,9 @@ class Message(DiscordObjectBase):
         self.edited_timestamp = datetime.datetime.fromisoformat(self.__edited_timestamp) if self.__edited_timestamp else self.__edited_timestamp
         self.tts = resp["tts"]
         self.mention_everyone = resp["mention_everyone"]
-        self.mentions = resp["mentions"]
-        self.mention_roles = [Role(self.client, x) for x in resp["mention_roles"]]
+        self.mentions = [GuildMember.create(self.client, x["member"], user=User.create(self.client, x), guild_id=self.guild_id)
+                         if "member" in x else User.create(self.client, x) for x in resp["mentions"]]
+        self.mention_roles = [Snowflake(x) for x in resp["mention_roles"]]
         self.mention_channels = [ChannelMention(x) for x in resp.get("mention_channels", [])]
         self.attachments = [Attachment(self.client, x) for x in resp["attachments"] or []]
         self.embeds = [Embed.create(x) for x in resp["embeds"] or []]
@@ -220,7 +239,7 @@ class Message(DiscordObjectBase):
         self.__interaction = resp.get("interaction")
         self.interaction = MessageInteraction(self.client, self.__interaction) if self.__interaction else self.__interaction
         self.__thread = resp.get("thread")
-        self.thread = Channel.create(self.client, self.__thread, guild_id=self.guild_id) if self.__thread else self.__thread
+        self.thread = Channel.create(self.client, self.__thread, guild_id=self.guild_id, ensure_cache_type="channel") if self.__thread else self.__thread
         self.components = [Component.auto_detect(x) for x in resp.get("components", [])]
 
     def reply(self, content=None, **kwargs):
@@ -242,12 +261,12 @@ class Message(DiscordObjectBase):
             return self.client.edit_interaction_response(**kwargs)
         return self.client.edit_message(self.channel_id, self.id, **kwargs)
 
-    def delete(self):
+    def delete(self, *, reason: str = None):
         if self.__webhook_token:
             return self.client.delete_webhook_message(self.webhook_id, self, webhook_token=self.__webhook_token)
         elif self.__interaction_token:
             return self.client.delete_interaction_response(interaction_token=self.__interaction_token, message="@original" if self.__original_response else self)
-        return self.client.delete_message(self.channel_id, self.id)
+        return self.client.delete_message(self.channel_id, self.id, reason=reason)
 
     def crosspost(self):
         return self.client.crosspost_message(self.channel_id, self.id)
@@ -258,14 +277,14 @@ class Message(DiscordObjectBase):
     def delete_reaction(self, emoji: typing.Union[Emoji, str], user: typing.Union[int, str, Snowflake, User] = "@me"):
         return self.client.delete_reaction(self.channel_id, self.id, emoji, user)
 
-    def pin(self):
-        return self.client.pin_message(self.channel_id, self.id)
+    def pin(self, *, reason: str = None):
+        return self.client.pin_message(self.channel_id, self.id, reason=reason)
 
-    def unpin(self):
-        return self.client.unpin_message(self.channel_id, self.id)
+    def unpin(self, *, reason: str = None):
+        return self.client.unpin_message(self.channel_id, self.id, reason=reason)
 
-    def start_thread(self, *, name: str, auto_archive_duration: int):
-        return self.client.start_thread(self.channel_id, name=name, auto_archive_duration=auto_archive_duration)
+    def start_thread(self, *, name: str, auto_archive_duration: int, reason: str = None):
+        return self.client.start_thread(self.channel_id, self, name=name, auto_archive_duration=auto_archive_duration, reason=reason)
 
     @property
     def guild(self):
@@ -360,10 +379,15 @@ class MessageReference:
         self.fail_if_not_exists = resp.get("fail_if_not_exists", True)
 
     def to_dict(self):
-        return {"message_id": str(self.message_id),
-                "channel_id": str(self.channel_id),
-                "guild_id": str(self.guild_id),
-                "fail_if_not_exists": self.fail_if_not_exists}
+        resp = {}
+        if self.message_id:
+            resp["message_id"] = str(self.message_id)
+        if self.channel_id:
+            resp["channel_id"] = str(self.channel_id)
+        if self.guild_id:
+            resp["guild_id"] = str(self.guild_id)
+        resp["fail_if_not_exists"] = self.fail_if_not_exists
+        return resp
 
     @classmethod
     def from_message(cls, message: Message, fail_if_not_exists: bool = True):
@@ -394,11 +418,18 @@ class Reaction:
 
 
 class Overwrite(CopyableObject):
-    def __init__(self, resp):
-        self.id = Snowflake(resp["id"])
-        self.type = resp["type"]
-        self.allow = PermissionFlags.from_value(int(resp["allow"]))
-        self.deny = PermissionFlags.from_value(int(resp["deny"]))
+    def __init__(self,
+                 user: typing.Union[str, int, Snowflake, User] = None,
+                 role: typing.Union[str, int, Snowflake, Role] = None,
+                 allow: typing.Union[int, PermissionFlags] = 0,
+                 deny: typing.Union[int, PermissionFlags] = 0,
+                 **kw):
+        if user is None and role is None:
+            raise TypeError("you must pass user or role.")
+        self.id = Snowflake.ensure_snowflake(int(user or role))
+        self.type = 0 if role else 1
+        self.allow = PermissionFlags.from_value(int(allow))
+        self.deny = PermissionFlags.from_value(int(deny))
 
     def to_dict(self):
         return {"id": str(self.id), "type": self.type, "allow": str(int(self.allow)), "deny": str(int(self.deny))}
@@ -409,14 +440,15 @@ class Overwrite(CopyableObject):
             self.deny.__setattr__(k, not v)
 
     @classmethod
-    def create(cls,
-               user: typing.Union[str, int, Snowflake, User] = None,
-               role: typing.Union[str, int, Snowflake, Role] = None,
-               allow: typing.Union[int, PermissionFlags] = 0,
-               deny: typing.Union[int, PermissionFlags] = 0):
-        if user is None and role is None:
-            raise TypeError("you must pass user or role.")
-        return cls(dict(id=int(user or role), type=0 if role else 1, allow=allow, deny=deny))
+    def create(cls, resp: dict):
+        resp = resp.copy()
+        _id = resp.pop("id")
+        _type = resp.pop("type")
+        if _type == 1:
+            resp["user"] = _id
+        elif _type == 0:
+            resp["role"] = _id
+        return cls(**resp)
 
 
 class ThreadMetadata:
@@ -457,6 +489,11 @@ class ThreadMember:
         if resp:
             return cls(client, resp)
 
+    @classmethod
+    def create(cls, *args):
+        """This is just a placeholder to prevent AttributeError."""
+        return cls(*args)
+
 
 class Embed(CopyableObject):
     def __init__(self, *, title: str = None, description: str = None, url: str = None, timestamp: datetime.datetime = None, color: int = None, **kwargs):
@@ -776,4 +813,4 @@ class ListThreadsResponse:
     def __init__(self, client, resp):
         self.threads = [Channel.create(client, x) for x in resp["threads"]]
         self.members = [ThreadMember(client, x) for x in resp["members"]]
-        self.has_more = resp["has_more"]
+        self.has_more = resp.get("has_more")
