@@ -10,6 +10,8 @@ from ..base.model import DiscordObjectBase, TypeBase, FlagBase
 
 
 class Guild(DiscordObjectBase):
+    TYPING = typing.Union[int, str, Snowflake, "Guild"]
+
     def __init__(self, client, resp):
         from .channel import Channel  # Prevent circular import.
         super().__init__(client, resp)
@@ -80,6 +82,37 @@ class Guild(DiscordObjectBase):
         if self.banner:
             return cdn_url("banners/{guild_id}", image_hash=self.banner, extension=extension, size=size, guild_id=self.id)
 
+    def request_preview(self):
+        return self.client.request_guild_preview(self)
+
+    def delete(self):
+        return self.client.delete_guild(self)
+
+    def modify(self, **kwargs):
+        return self.client.modify_guild(self, **kwargs)
+
+    @property
+    def edit(self):
+        return self.modify
+
+    def request_channels(self):
+        return self.client.request_guild_channels(self)
+
+    def create_channel(self, name: str, **kwargs):
+        return self.client.create_guild_channel(self, name, **kwargs)
+
+    def modify_channel_positions(self, *params: dict, reason: str = None):
+        return self.client.modify_guild_channel_positions(self, *params, reason=reason)
+
+    def list_active_threads(self):
+        return self.client.list_active_threads_as_guild(self)
+
+    def request_member(self, user: typing.Union[int, str, Snowflake, User]):
+        return self.client.request_guild_member(self, user)
+
+    def list_members(self, limit: int = None, after: str = None):
+        return self.client.list_guild_members(self, limit, after)
+
     def remove_guild_member(self, user: typing.Union[int, str, Snowflake, User]):
         return self.client.remove_guild_member(self, user)
 
@@ -163,6 +196,8 @@ class GuildWidget:
 
 
 class GuildMember:
+    TYPING = typing.Union[int, str, Snowflake, "GuildMember"]
+
     def __init__(self, client, resp, *, user: User = None, guild_id=None):
         self.raw = resp
         self.client = client
@@ -228,3 +263,73 @@ class GuildMember:
         if cache and client.has_cache and ret.guild_id and ret.user:
             client.cache.get_guild_container(ret.guild_id).add(ret.user.id, "member", ret)
         return ret
+
+
+class Integration:
+    TYPING = typing.Union[int, str, Snowflake, "Integration"]
+
+    def __init__(self, client, resp):
+        self.id = Snowflake(resp["id"])
+        self.name = resp["name"]
+        self.type = resp["type"]
+        self.enabled = resp["enabled"]
+        self.syncing = resp.get("syncing")
+        self.role_id = Snowflake.optional(resp.get("role_id"))
+        self.enable_emoticons = resp.get("enable_emoticons")
+        self.__expire_behavior = resp.get("expire_behavior")
+        self.expire_behavior = IntegrationExpireBehaviors(int(self.__expire_behavior)) if self.__expire_behavior else self.__expire_behavior
+        self.expire_grace_period = resp.get("expire_grace_period")
+        self.__user = resp.get("user")
+        self.user = User.create(client, self.__user) if self.__user else self.__user
+        self.account = IntegrationAccount(resp["account"])
+        self.__synced_at = resp.get("synced_at")
+        self.synced_at = datetime.datetime.fromisoformat(self.__synced_at) if self.__synced_at else self.__synced_at
+        self.subscriber_count = resp.get("subscriber_count")
+        self.revoked = resp.get("revoked")
+        self.__application = resp.get("application")
+        self.application = IntegrationApplication(client, self.__application) if self.__application else self.__application
+
+    def __int__(self):
+        return int(self.id)
+
+
+class IntegrationExpireBehaviors(TypeBase):
+    REMOVE_ROLE = 0
+    KICK = 1
+
+
+class IntegrationAccount:
+    def __init__(self, resp):
+        self.id = resp["id"]
+        self.name = resp["name"]
+
+
+class IntegrationApplication:
+    def __init__(self, client, resp):
+        self.id = Snowflake(resp["id"])
+        self.name = resp["name"]
+        self.icon = resp["icon"]
+        self.description = resp["description"]
+        self.summary = resp["summary"]
+        self.__bot = resp.get("bot")
+        self.bot = User.create(client, self.__bot) if self.__bot else self.__bot
+
+    def icon_url(self, *, extension="webp", size=1024):
+        return cdn_url("app-icons/{application_id}", image_hash=self.icon, extension=extension, size=size, application_id=self.id)
+
+
+class Ban:
+    def __init__(self, client, resp):
+        self.reason = resp["reason"]
+        self.user = User.create(client, resp["user"])
+
+
+# TODO: Welcome Screen
+
+
+class PruneCountResponse:
+    def __init__(self, resp: dict):
+        self.pruned = resp["pruned"]
+
+    def __int__(self):
+        return int(self.pruned)
