@@ -59,6 +59,15 @@ class WebSocketClient:
                         self.logger.warning("Trying to reconnect...")
                         await self.reconnect(fresh=True)
                     break
+                if not resp:
+                    # self.logger.warning("Empty response detected, ignoring.")
+                    # continue
+
+                    # Actually, we should terminate or we might have 500MB+ logger file ¯\_(ツ)_/¯
+                    await self.close(1001)
+                    raise Exception("Uh oh, it looks like you just encountered some annoying issue. For the safety, this client will automatically closed.\n"
+                                    "If you have the logger set to DEBUG mode, please report this issue with 4~5 previous raw response lof to GitHub issue #1 or our support server.\n"
+                                    "Sorry for the inconvenience.")
                 self.logger.debug(f"Received `{gateway.Opcodes.as_string(resp.op)}` payload"
                                   f"{f' with event name `{resp.t}`' if resp.op == gateway.Opcodes.DISPATCH else ''}.")
                 if resp.s:
@@ -102,6 +111,7 @@ class WebSocketClient:
 
     async def receive(self):
         resp = await self.ws.receive()
+        self.logger.debug(f"Raw receive {resp.type}: {resp.data}")
         if resp.type == aiohttp.WSMsgType.TEXT:
             res = gateway.GatewayResponse(resp.json())
             if res.s is not None:
